@@ -48,75 +48,14 @@ int objRemoved = 0;
 #define VERBOSE 0
 
 /////////// ICONIFY STUFF /////////////
-/* to iconify an existing window */
-static void gdk_window_iconize (GdkWindow *window);
-/* to maximise an existing window */
-static void window_deiconify (GdkWindow *window);
 /* to test if ... */
 static gboolean window_is_iconified (GdkWindow *window);
-
-/* to iconify an existing window */
-/*
-void gdk_window_iconize (GdkWindow *window)
-{
-  GdkWindowPrivate *Private;
-  g_return_if_fail (window != NULL);
-  Private = (GdkWindowPrivate*) window;
-  if (!Private->destroyed)
-    XIconifyWindow (Private->xdisplay, Private->xwindow,0);
-}
-*/
-/*
-  mm september 9, 2000
-  This is another version stolen to:
-  Anders Melchiorsen <and@kampsax.dtu.dk>
-  It should be better since does nto use any private field.
-*/
-void gdk_window_iconize (GdkWindow *window)
-{
-  XIconifyWindow(GDK_WINDOW_XDISPLAY(window),
-		 GDK_WINDOW_XWINDOW(window),
-		 DefaultScreen (GDK_DISPLAY ()));
-}
-
-/* to maximise an existing window */
-/*
-void
-window_deiconify (GdkWindow *window)
-{
-  GdkWindowPrivate *Private;
-  g_return_if_fail (window != NULL);
-  Private = (GdkWindowPrivate*) window;
-  XMapRaised (Private->xdisplay, Private->xwindow);
-}
-*/
-/*
-  mm september 9, 2000
-  This is another version stolen to:
-  Anders Melchiorsen <and@kampsax.dtu.dk>
-  It should be better since does nto use any private field.
-*/
-void
-window_deiconify (GdkWindow *window)
-{
-  // This maps the window, which also de-iconifies it according
-  // to ICCCM.
-  gdk_window_raise(window);
-  gdk_flush();
-  gdk_window_show(window);
-  gdk_flush();
-}
-
 /* to test if window is iconized */
 gboolean
 window_is_iconified (GdkWindow *window)
 {
   XWindowAttributes xattr;
-  GdkWindowPrivate *Private;
-  g_return_val_if_fail (window != NULL,false);
-  Private = (GdkWindowPrivate*) window;
-  xattr.map_state = IsUnmapped;
-  XGetWindowAttributes(Private->xdisplay, Private->xwindow, &xattr);
+  XGetWindowAttributes(GDK_WINDOW_XDISPLAY(window), GDK_WINDOW_XWINDOW(window), &xattr);
   return (xattr.map_state == IsUnmapped);
 }
 /*
@@ -132,24 +71,16 @@ VDKForm::GetIconized()
 void
 VDKForm::SetIconized(bool flag)
 {
-  /*
-    // mm 06.07.99
-    // change to do not iconize childs
-    // autonomously
-    ChildListIterator li(Childs());
-    for(;li;li++)
-    li.current()->SetIconized(flag);
-  */
-if(flag  && ! GetIconized())
-  {
-    gdk_window_iconize(window->window);
-    OnIconize(this);
-  }
-else if (! flag && GetIconized())
-  {
-    window_deiconify(window->window);
-    OnRestore(this);
-  }
+  if(flag  && ! GetIconized())
+    {
+      gtk_window_iconify(GTK_WINDOW(window));
+      OnIconize(this);
+    }
+  else if (! flag && GetIconized())
+    {
+      gtk_window_deiconify(GTK_WINDOW(window));
+      OnRestore(this);
+    }
 }
 /*
  */
@@ -205,7 +136,6 @@ VDKForm::DestroyEvent (GtkWidget*, gpointer gp)
     {
       form->Owner()->modalCount--;
       gtk_window_set_modal (GTK_WINDOW(form->Window()),FALSE);
-      //gtk_grab_remove(form->Window());
       gtk_main_quit();
     }
   // Only MainForm does not have parent, so closes application
@@ -257,19 +187,8 @@ VDKForm::ConfigureEvent(GtkWidget* wid ,
       form->_oldPos = p;
       form->OnMove(form);
     }
-  else if(s != form->_oldSize)
-    {
-      form->_oldSize = s;
-      // to mantain backward compat
-      int version  = gtk_major_version*100;
-      version += gtk_minor_version*10;
-      version += gtk_micro_version;
-      // this does not works on all wm's
-      //      if(version <= 125)
-	form->OnResize(form,s);
-    }
   form->OnConfigure(form);
-  return TRUE;
+  return FALSE;// TRUE;
 }
 
 void
@@ -283,11 +202,9 @@ VDKForm::SizeAllocateSignal(GtkWidget      *widget,
   printf("\nVDKForm::SizeAllocateSignal()");
   fflush(stdout);
 #endif
-  if(s != form->_oldSize)
+    if(s != form->_oldSize)
     {
       form->_oldSize = s;
-      if(!form->never_showed)
-	{
 #if VERBOSE
 	  printf("\nold size(%d,%d) - new size(%d,%d)",
 		 form->_oldSize.x,
@@ -296,8 +213,7 @@ VDKForm::SizeAllocateSignal(GtkWidget      *widget,
 		 s.y);
 	  fflush(stdout);
 #endif
-	form->OnResize(form,s);
-	}
+	  form->OnResize(form,s);
     }
 }
 /*
@@ -314,36 +230,53 @@ VDKForm::ExposeEvent(GtkWidget* , GdkEventExpose* ev, gpointer gp)
       VDKForm* form = reinterpret_cast<VDKForm*>(gp);
       form->OnExpose(form, ev->area);
     }
-  return TRUE;
+  return FALSE; //TRUE;
 }
 /*
  */
-void VDKForm::RealizeSignal(GtkWidget* , gpointer gp)
+void 
+VDKForm::RealizeSignal(GtkWidget* , gpointer gp)
 {
   g_return_if_fail(gp != NULL);
   VDKForm* form = reinterpret_cast<VDKForm*>(gp);
   VDKPoint pos = form->Position;
   form->OnRealize(form);
 }
-/*
- */
-int VDKForm::MapEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
+
+int 
+VDKForm::MapEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
 {
   g_return_val_if_fail(gp != NULL, FALSE);
   VDKForm* form = reinterpret_cast<VDKForm*>(gp);
   if( ! form->never_showed)
     form->OnRestore(form);
-  return TRUE;
+  return FALSE;// TRUE;
 }
-/*
- */
-int VDKForm::UnmapEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
+
+
+int 
+VDKForm::UnmapEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
 {
   g_return_val_if_fail(gp != NULL, FALSE);
   VDKForm* form = reinterpret_cast<VDKForm*>(gp);
   form->OnIconize(form);
-  return TRUE;
+  return FALSE;// TRUE;
 }
+
+/*
+ */
+gboolean 
+VDKForm::WindowStateEvent (GtkWidget	     *widget,
+			   GdkEventWindowState *event)
+{
+#if VERBOSE
+  printf("\nWindowStateEvent - changed_masks:%d - new_state:%d",
+	 event->changed_mask,event->new_window_state);
+  fflush(stdout);
+#endif
+  return FALSE;
+}
+
 /*
  */
 int VDKForm::FocusInEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
@@ -351,7 +284,7 @@ int VDKForm::FocusInEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
   g_return_val_if_fail(gp != NULL, FALSE);
   VDKForm* form = reinterpret_cast<VDKForm*>(gp);
   form->OnFormActivate(form,true);
-  return TRUE;
+  return FALSE; //TRUE;
 }
 /*
  */
@@ -360,7 +293,7 @@ int VDKForm::FocusOutEvent(GtkWidget* , GdkEvent* ev ,gpointer gp)
   g_return_val_if_fail(gp != NULL, FALSE);
   VDKForm* form = reinterpret_cast<VDKForm*>(gp);
   form->OnFormActivate(form,false);
-  return TRUE;
+  return FALSE; //TRUE;
 }
 /*
 ==================================================
@@ -393,40 +326,17 @@ VDKForm::VDKForm(VDKApplication* app, gchar *title,
     gtk_window_set_title(GTK_WINDOW(window),title);
   // sets the border width of the window
   gtk_container_border_width (GTK_CONTAINER (window),2);
-  // gtk+1.2.4
   box = new VDKBox(this,mode);
   items.add(box);
   gtk_widget_set_name(box->Widget(),"VDKForm::Box");
   gtk_container_add(GTK_CONTAINER(window),box->Widget());
   gtk_widget_show(box->Widget());
   box->Parent(this);
-  /*
-    gross hack to avoid
-    dangerous allocation warning
-    thanks to TJ
-    (should be renoved when gtk+ bug
-    will be fixed)
-  */
-  int gtk_version = gtk_major_version *100 +
-		    gtk_minor_version * 10 +
-		    gtk_micro_version;
-  if (gtk_version <= 124)
-      {
-	  GtkRequisition requisition;
-	  GtkAllocation allocation = { 0, 0, 200, 200 };
-	  gtk_widget_size_request (window, &requisition);
-	  if (requisition.width || requisition.height)
-	      {
-		  allocation.width = requisition.width;
-		  allocation.height = requisition.height ;
-	      }	
-	  gtk_widget_size_allocate (window, &allocation);
-      }
 	
   //////////////////////////////////////////////
-  gtk_widget_realize(window);
   //connect signals
   SignalsConnect();
+  gtk_widget_realize(window);
 #ifdef VDKDEBUG
   formC++;
 #endif
@@ -442,25 +352,27 @@ void VDKForm::SignalsConnect()
 		      GTK_SIGNAL_FUNC (VDKForm::DestroyEvent), this);
   gtk_signal_connect (GTK_OBJECT (window), "configure_event",
 		      GTK_SIGNAL_FUNC(VDKForm::ConfigureEvent),this);
-  gtk_signal_connect (GTK_OBJECT (window), "expose_event",
-		      GTK_SIGNAL_FUNC(VDKForm::ExposeEvent),this);
   gtk_signal_connect(GTK_OBJECT(window),"realize",
 		     GTK_SIGNAL_FUNC(VDKForm::RealizeSignal),this);
+  gtk_signal_connect(GTK_OBJECT (window), "expose_event",
+		      GTK_SIGNAL_FUNC(VDKForm::ExposeEvent),this);
+
   gtk_signal_connect(GTK_OBJECT(window),"map_event",
 		     GTK_SIGNAL_FUNC(VDKForm::MapEvent),this);
   gtk_signal_connect(GTK_OBJECT(window),"unmap_event",
 		     GTK_SIGNAL_FUNC(VDKForm::UnmapEvent),this);
+
   gtk_signal_connect(GTK_OBJECT(window),"focus_in_event",
 		     GTK_SIGNAL_FUNC(VDKForm::FocusInEvent),this);
   gtk_signal_connect(GTK_OBJECT(window),"focus_out_event",
 		     GTK_SIGNAL_FUNC(VDKForm::FocusOutEvent),this);
-  // to mantain backward compat
-  int version  = gtk_major_version*100;
-  version += gtk_minor_version*10;
-  version += gtk_micro_version;
-  //  if(version > 125)
-  //  gtk_signal_connect(GTK_OBJECT(window),"size_allocate",
-  //	       GTK_SIGNAL_FUNC(VDKForm::SizeAllocateSignal),this);
+
+  gtk_signal_connect_after(GTK_OBJECT(window),"size_allocate",
+  	       GTK_SIGNAL_FUNC(VDKForm::SizeAllocateSignal),this);
+  /*
+  gtk_signal_connect_after(GTK_OBJECT(window),"window_state_event",
+  	       GTK_SIGNAL_FUNC(VDKForm::WindowStateEvent),this);
+  */
   gtk_widget_add_events(Window(),GDK_KEY_RELEASE_MASK);
   gtk_widget_add_events(Window(),GDK_KEY_PRESS_MASK);
 }
@@ -490,42 +402,17 @@ VDKForm::VDKForm(VDKForm* owner, gchar* title ,
     gtk_window_set_title(GTK_WINDOW(window),title);
   // sets the border width of the window
   gtk_container_border_width (GTK_CONTAINER (window), 1);
-
   box = new VDKBox(this,mode);
   items.add(box);
   gtk_widget_set_name(box->Widget(),"VDKForm::Box");
   gtk_container_add(GTK_CONTAINER(window),box->Widget());
   gtk_widget_show(box->Widget());
   box->Parent(this);
-  /*	
-	gross hack to avoid
-	dangerous allocation warning
-	thanks to TJ
-	(should be renoved when gtk+ bug
-	will be fixed)
-  */
-  int gtk_version = gtk_major_version *100 +
-		    gtk_minor_version * 10 +
-		    gtk_micro_version;
-  if (gtk_version <= 124)
-      {
-	  GtkRequisition requisition;
-	  GtkAllocation allocation = { 0, 0, 200, 200 };
-	  gtk_widget_size_request (window, &requisition);
-	  if (requisition.width || requisition.height)
-	      {
-		  allocation.width = requisition.width;
-		  allocation.height = requisition.height ;
-	      }
-	  gtk_widget_size_allocate (window, &allocation);
-      }	
-
   //////////////////////////////////////////////
-  gtk_widget_realize(window);
   // connect signals
   SignalsConnect();
+  gtk_widget_realize(window);
   owner->AddChild(this);
-
 #ifdef VDKDEBUG
   formC++;
 #endif
@@ -760,7 +647,8 @@ void VDKForm::Close(void)
 
   if( GTK_IS_WIDGET(window) && !DeleteEvent(NULL,NULL,this))
     gtk_widget_destroy(window);
-}
+} 
+
 /*
 closes form childs
 (internally used)
@@ -840,16 +728,20 @@ VDKForm::GetPosition()
 {
   int x = -1,y = -1;
   VDKPoint p(x,y);
+  /*
   if(window->window && (!never_showed))
     {
-      // gdk_window_get_root_origin(window->window,&x,&y);
-      gdk_window_get_deskrelative_origin(window->window,&x,&y);
+  */
+     gdk_window_get_root_origin(window->window,&x,&y);
+     //gdk_window_get_deskrelative_origin(window->window,&x,&y);
       // gdk_window_get_position (window->window,&x,&y);
       p.x = x;
       p.y = y;
+      /*
     }
   else
     p = VDKPoint(window->allocation.x,window->allocation.y);
+      */
   return p;
 }
 /*
@@ -879,7 +771,7 @@ VDKForm::SetBackgroundPixmap(VDKRawPixmap* pix)
   if(pix == NULL) 
      style->bg_pixmap[GTK_STATE_NORMAL] = NULL; 
   else  
-    style->bg_pixmap[GTK_STATE_NORMAL] = *pix; 
+    style->bg_pixmap[GTK_STATE_NORMAL] = pix->AsGdkPixmap(); 
   //  style->bg_pixmap[GTK_STATE_NORMAL] = pix ? *pix : NULL;
   gtk_widget_set_style( Window(), style );
   /*
